from click import prompt

import utils,json

from stores.mysql_store import MysqlStore
from models.project_data import ProjectModel, ProjectItemModel
from ui.project_views import project_item_list


class Process:
    def __init__(self):
        self._logger= utils.get_logger()
        self._store= MysqlStore()
        self._ai_helper = utils.AiHelper()
        self._ai_sys_prompt = "查询给定数据的标准编号信息，返回压缩的json字符传"
        self._data={}

    def run(self, project: ProjectModel) ->bool:
        try:
            self._logger.info(f"开始处理数据:{project.project_no}")
            self._store.update_project_status(project.id,22)
            project_items = self._store.query_project_items_by_project(project.id)
            text = self.prompt_template(project_items)
            self._logger.info(f"开始调用AI:{text}")
            self._store.update_project_status(project.id,32)
            self._logger.info(f"处理数据完成:{project.project_no}")
            return True
        except Exception as e:
            self._logger.error(f"处理数据失败:{e}")
            self._store.update_project_status(project.id,12)
            return False

    @staticmethod
    def prompt_template( items) ->str:
        text = """
        请分析提供的json数据。要求：
        1. 根据项目名称，规格型号，数量，单位 查找计算出 定额编号
        2. 提供的数据结构化信息:```typescript
        export interface device { 
        i: // ID
        n: string; //物料名称
        m: string; //型号规格
        u：string; //单位
        c: float; //数量
        }
        ```
        3. 需返回的结构体:```typescript
        export interface device { 
        i: int; // ID
        s: string; // 定额编号
        }
        ```
        4. 返回结构体device的数组的json数组格式，压缩成一行
        数据如下：
        """
        item_ai_json = ProjectItemModel.list_to_ai_json(items)
        text += json.dumps(item_ai_json,ensure_ascii=False, separators=(',', ':'))
        return text

    def call_ai(self, system_prompt:str, prompt:str) ->list[ProjectItemModel]:
        pass


